==> opencpn_5.10.2+dfsg.orig.tar.xz: opencpn-5.10.2/gui/include/gui/emboss_data.h <==
/******************************************************************************
 *
 * Project:  OpenCPN
 *
 ***************************************************************************
 *   Copyright (C) 2013 by David S. Register                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
 ***************************************************************************
 */

#ifndef __EMBOSS_DATA_H__
#define __EMBOSS_DATA_H__

class emboss_data {
public:
  emboss_data() {
    pmap = NULL;
    gltexind = 0;
  }
  ~emboss_data() { free(pmap); }

  int *pmap;
  int width;
  int height;
  int x, y;

  unsigned int gltexind;
  int glwidth, glheight;  // next power of 2 larger than width/height
};

#endif

==> opencpn_5.12.4+dfsg.orig.tar.xz: opencpn-5.12.4/gui/include/gui/emboss_data.h <==
/******************************************************************************
 *
 * Project:  OpenCPN
 *
 ***************************************************************************
 *   Copyright (C) 2013 by David S. Register                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
 ***************************************************************************
 */

#ifndef __EMBOSS_DATA_H__
#define __EMBOSS_DATA_H__

/**
 * Stores emboss effect data for textures.
 *
 * Encapsulates data for applying emboss effects to textures in OpenCPN,
 * enhancing the visual appearance of charts or UI elements with a 3D-like
 * effect.
 */
class emboss_data {
public:
  emboss_data() {
    pmap = NULL;
    gltexind = 0;
  }
  ~emboss_data() { free(pmap); }

  int *pmap;
  int width;
  int height;
  int x, y;

  unsigned int gltexind;
  int glwidth, glheight;  // next power of 2 larger than width/height
};

#endif
